@@ -52,7 +52,7 @@ package App::wsgetmail;
 
 use Moo;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 NAME
 
@@ -73,6 +73,7 @@ where C<wsgetmail.json> looks like:
     "global_access": 1,
     "username": "rt-comment@example.com",
     "folder": "Inbox",
+    "strip_cr": 0,
     "command": "/opt/rt5/bin/rt-mailgate",
     "command_args": "--url=http://rt.example.com/ --queue=General --action=comment",
     "command_timeout": 30,
@@ -411,6 +412,14 @@ configuration file.
 
 Set this to the name string of a mail folder to read.
 
+=item strip_cr
+
+Set this to 1 to make wsgetmail convert the messages from the CRLF
+line-ending encoding to the LF line-ending encoding.
+
+This is technically not standards-compliant, but some unix utilities
+don't work with CRLF line-endings.
+
 =item command
 
 Set this to an executable command. You can specify an absolute path,
@@ -428,7 +437,7 @@ double quotes.
 =item command_timeout
 
 Set this to the number of seconds the C<command> has to return before
-timeout is reached.  The default value is 30.
+timeout is reached.  The default value is 30.  Use "inf" for no timeout.
 
 =item action_on_fetched
 
@@ -440,6 +449,12 @@ If you set this to C<"mark_as_read">, wsgetmail will only retrieve and
 deliver messages that are marked unread in the configured folder, so it does
 not try to deliver the same email multiple times.
 
+=item dump_messages
+
+Set this to 1 to preserve the temporary files after processing.
+
+When C<"debug"> is also set the filenames will be reported on STDERR.
+
 =back
 
 =head1 TESTING AND DEPLOYMENT
@@ -456,6 +471,20 @@ runs successfully.
 Once your configuration is stable, you can configure wsgetmail to run
 periodically through cron or a systemd service on a timer.
 
+=head1 ERRORS AND DIAGNOSTIC MESSAGES
+
+wsgetmail sends warning, error, and debug messages to STDERR, while purely
+informational messages are sent to STDOUT.  Operators may want to capture both
+output streams as a merged stream for diagnostic purposes.  For example:
+
+    wsgetmail --debug --dry-run --config=wsgetmail.json > wsgetmail.debug 2>&1
+
+When the mail processing command exits with an error (non-zero) status the
+action_on_fetched is not performed on that message so that it will be processed
+on the next run.
+
+Full output of the processing command is produced with C<--debug>.
+
 =head1 LIMITATIONS
 
 =head2 Fetching from Multiple Folders
@@ -506,7 +535,7 @@ Best Practical Solutions, LLC <modules@bestpractical.com>
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is Copyright (c) 2015-2020 by Best Practical Solutions, LLC.
+This software is Copyright (c) 2015-2022 by Best Practical Solutions, LLC.
 
 This is free software, licensed under:
 
